@@ -284,15 +284,6 @@ retrieve_d_bitfield(core::Download* download) {
   return torrent::Object(rak::transform_hex(bitField->begin(), bitField->end()));
 }
 
-// Just a helper function atm.
-torrent::Object
-cmd_d_initialize_logs(core::Download* download) {
-  download->info()->signal_network_log().push_back(tr1::bind(&core::Manager::push_log_complete, control->core(), tr1::placeholders::_1));
-  download->info()->signal_storage_error().push_back(tr1::bind(&core::Manager::push_log_complete, control->core(), tr1::placeholders::_1));
-
-  return torrent::Object();
-}
-
 struct call_add_d_peer_t {
   call_add_d_peer_t(core::Download* d, int port) : m_download(d), m_port(port) { }
 
@@ -872,8 +863,6 @@ initialize_command_download() {
   CMD2_DL         ("d.group.name", tr1::bind(&cg_d_group, tr1::placeholders::_1));
   CMD2_DL_V       ("d.group.set",  tr1::bind(&cg_d_group_set, tr1::placeholders::_1, tr1::placeholders::_2));
 
-  CMD2_DL         ("d.initialize_logs", tr1::bind(&cmd_d_initialize_logs, tr1::placeholders::_1));
-
   CMD2_DL_LIST    ("f.multicall", tr1::bind(&f_multicall, tr1::placeholders::_1, tr1::placeholders::_2));
   CMD2_DL_LIST    ("p.multicall", tr1::bind(&p_multicall, tr1::placeholders::_1, tr1::placeholders::_2));
   CMD2_DL_LIST    ("t.multicall", tr1::bind(&t_multicall, tr1::placeholders::_1, tr1::placeholders::_2));
