@@ -48,8 +48,6 @@
 #include <torrent/chunk_manager.h>
 #include <torrent/data/file_manager.h>
 #include <torrent/data/chunk_utils.h>
-#include <torrent/utils/log.h>
-#include <torrent/utils/log_files.h>
 #include <torrent/utils/option_strings.h>
 
 #include "core/download.h"
@@ -80,63 +78,6 @@ apply_pieces_stats_total_size() {
   return size;
 }
 
-torrent::Object
-apply_log(const torrent::Object::string_type& arg, int logType) {
-  if (rpc::execFile.log_fd() != -1) {
-    switch (logType) {
-    case 0: ::close(rpc::execFile.log_fd()); rpc::execFile.set_log_fd(-1); break;
-    case 1:
-//       if (control->scgi()) {
-//         ::close(control->scgi()->log_fd());
-//         control->scgi()->set_log_fd(-1);
-//       }
-      break;
-    default: break;
-    }
-  }
-
-  if (!arg.empty()) {
-    int logFd = open(rak::path_expand(arg).c_str(), O_WRONLY | O_APPEND | O_CREAT, 0644);
-
-    if (logFd < 0)
-      throw torrent::input_error("Could not open execute log file.");
-
-    switch (logType) {
-    case 0: rpc::execFile.set_log_fd(logFd); break;
-//     case 1: if (control->scgi()) control->scgi()->set_log_fd(logFd); break;
-    default: break;
-    }
-
-    control->core()->push_log("Opened log file.");
-
-  } else {
-    control->core()->push_log("Closed log file.");
-  }
-
-  return torrent::Object();
-}
-
-torrent::Object
-apply_log_libtorrent(const torrent::Object::list_type& args) {
-  if (args.empty() || args.size() > 2)
-    throw torrent::input_error("Invalid argument count.");
-  
-  torrent::log_file* log_file = torrent::find_log_file(args.front().as_string().c_str());
-
-  if (log_file == NULL)
-    throw torrent::input_error("Invalid log name.");
-
-  if (args.size() == 1) {
-    log_file->close();
-    return torrent::Object();
-  }
-  
-  if (!log_file->open_file(args.back().as_string().c_str()))
-    throw torrent::input_error("Could not open log file.");
-
-  return torrent::Object();
-}
-
 torrent::Object
 system_hostname() {
   char buffer[1024];
@@ -234,27 +175,6 @@ group_insert(const torrent::Object::list_type& args) {
   return name;
 }
 
-torrent::Object
-log_vmmap_dump(const std::string& str) {
-  core::DownloadList* d_list = control->core()->download_list();
-  std::vector<torrent::vm_mapping> all_mappings;
-
-  for (core::DownloadList::iterator itr = d_list->begin(), last = d_list->end(); itr != last; itr++) {
-    std::vector<torrent::vm_mapping> tmp_mappings = torrent::chunk_list_mapping((*itr)->download());
-
-    all_mappings.insert(all_mappings.end(), tmp_mappings.begin(), tmp_mappings.end());    
-  }
-
-  FILE* log_file = fopen(str.c_str(), "w");
-
-  for (std::vector<torrent::vm_mapping>::iterator itr = all_mappings.begin(), last = all_mappings.end(); itr != last; itr++) {
-    fprintf(log_file, "%8p-%8p [%5llxk]\n", itr->ptr, (char*)itr->ptr + itr->length, (long long unsigned int)(itr->length / 1024));
-  }
-
-  fclose(log_file);
-  return torrent::Object();
-}
-
 static const int file_print_use_space = 0x1;
 static const int file_print_delim_space = 0x2;
 
@@ -299,26 +219,6 @@ cmd_file_append(const torrent::Object::list_type& args) {
   return torrent::Object();
 }
 
-torrent::Object
-apply_log_open_file(const torrent::Object::list_type& args) {
-  if (args.size() != 2)
-    throw torrent::input_error("Invalid number of arguments.");
-  
-  torrent::log_open_file_output(args.front().as_string().c_str(),
-                                rak::path_expand(args.back().as_string()).c_str());
-  return torrent::Object();
-}
-
-torrent::Object
-apply_log_add_output(const torrent::Object::list_type& args) {
-  if (args.size() != 2)
-    throw torrent::input_error("Invalid number of arguments.");
-  
-  torrent::log_add_group_output(torrent::option_find_string(torrent::OPTION_LOG_GROUP, args.front().as_string().c_str()),
-                                args.back().as_string().c_str());
-  return torrent::Object();
-}
-
 void
 initialize_command_local() {
   torrent::ChunkManager* chunkManager = torrent::chunk_manager();
@@ -338,7 +238,7 @@ initialize_command_local() {
   CMD2_VAR_STRING  ("system.file.split_suffix",     ".part");
 
   CMD2_ANY         ("system.file_status_cache.size",   tr1::bind(&utils::FileStatusCache::size,
-                                                                      (utils::FileStatusCache::base_type*)control->core()->file_status_cache()));
+                                                                 (utils::FileStatusCache::base_type*)control->core()->file_status_cache()));
   CMD2_ANY_V       ("system.file_status_cache.prune",  tr1::bind(&utils::FileStatusCache::prune, control->core()->file_status_cache()));
 
   CMD2_VAR_BOOL    ("file.prioritize_toc",          0);
@@ -413,14 +313,6 @@ initialize_command_local() {
   CMD2_EXECUTE     ("execute.capture",         rpc::ExecFile::flag_throw | rpc::ExecFile::flag_expand_tilde | rpc::ExecFile::flag_capture);
   CMD2_EXECUTE     ("execute.capture_nothrow", rpc::ExecFile::flag_expand_tilde | rpc::ExecFile::flag_capture);
 
-  CMD2_ANY_LIST    ("log.open_file",  tr1::bind(&apply_log_open_file, tr1::placeholders::_2));
-  CMD2_ANY_LIST    ("log.add_output", tr1::bind(&apply_log_add_output, tr1::placeholders::_2));
-
-  CMD2_ANY_STRING  ("log.execute",    tr1::bind(&apply_log, tr1::placeholders::_2, 0));
-  CMD2_ANY_STRING  ("log.vmmap.dump", tr1::bind(&log_vmmap_dump, tr1::placeholders::_2));
-  CMD2_ANY_STRING_V("log.xmlrpc",     tr1::bind(&ThreadWorker::set_xmlrpc_log, worker_thread, tr1::placeholders::_2));
-  CMD2_ANY_LIST    ("log.libtorrent", tr1::bind(&apply_log_libtorrent, tr1::placeholders::_2));
-
   CMD2_ANY_LIST    ("file.append",    tr1::bind(&cmd_file_append, tr1::placeholders::_2));
 
   // TODO: Convert to new command types:
