@@ -42,9 +42,9 @@
 #define RTORRENT_CORE_DOWNLOAD_FACTORY_H
 
 #include <iosfwd>
-#include <sigc++/functors/slot.h>
 #include <rak/priority_queue_default.h>
 #include <torrent/object.h>
+#include <tr1/functional>
 
 #include "http_queue.h"
 
@@ -54,7 +54,7 @@ class Manager;
 
 class DownloadFactory {
 public:
-  typedef sigc::slot<void> Slot;
+  typedef std::tr1::function<void ()> slot_void;
   typedef std::vector<std::string> command_list_type;
 
   // Do not destroy this object while it is in a HttpQueue.
@@ -80,7 +80,7 @@ public:
   bool                print_log() const     { return m_printLog; }
   void                set_print_log(bool v) { m_printLog = v; }
 
-  void                slot_finished(Slot s) { m_slotFinished = s; }
+  void                slot_finished(slot_void s) { m_slot_finished = s; }
 
 private:
   void                receive_load();
@@ -109,7 +109,7 @@ private:
   command_list_type         m_commands;
   torrent::Object::map_type m_variables;
 
-  Slot                m_slotFinished;
+  slot_void           m_slot_finished;
   rak::priority_item  m_taskLoad;
   rak::priority_item  m_taskCommit;
 };
