@@ -38,8 +38,6 @@
 
 #include <memory>
 #include <sstream>
-#include <sigc++/adaptors/bind.h>
-#include <sigc++/adaptors/hide.h>
 #include <torrent/http.h>
 
 #include "rak/functional.h"
@@ -50,31 +48,34 @@ namespace core {
 
 HttpQueue::iterator
 HttpQueue::insert(const std::string& url, std::iostream* s) {
-  std::auto_ptr<CurlGet> h(m_slotFactory());
+  std::auto_ptr<CurlGet> h(m_slot_factory());
   
   h->set_url(url);
   h->set_stream(s);
   h->set_timeout(5 * 60);
 
-  iterator itr = Base::insert(end(), h.get());
+  iterator signal_itr = base_type::insert(end(), h.get());
 
-  h->signal_done().push_back(std::tr1::bind(&HttpQueue::erase, this, itr));
-  h->signal_failed().push_back(std::tr1::bind(&HttpQueue::erase, this, itr));
+  h->signal_done().push_back(std::tr1::bind(&HttpQueue::erase, this, signal_itr));
+  h->signal_failed().push_back(std::tr1::bind(&HttpQueue::erase, this, signal_itr));
 
-  (*itr)->start();
+  (*signal_itr)->start();
 
   h.release();
-  m_signalInsert.emit(*itr);
 
-  return itr;
+  for (signal_curl_get::iterator itr = m_signal_insert.begin(), last = m_signal_insert.end(); itr != last; itr++)
+    (*itr)(*signal_itr);
+
+  return signal_itr;
 }
 
 void
-HttpQueue::erase(iterator itr) {
-  m_signalErase.emit(*itr);
+HttpQueue::erase(iterator signal_itr) {
+  for (signal_curl_get::iterator itr = m_signal_erase.begin(), last = m_signal_erase.end(); itr != last; itr++)
+    (*itr)(*signal_itr);
 
-  delete *itr;
-  Base::erase(itr);
+  delete *signal_itr;
+  base_type::erase(signal_itr);
 }
 
 void
@@ -82,7 +83,7 @@ HttpQueue::clear() {
   while (!empty())
     erase(begin());
 
-  Base::clear();
+  base_type::clear();
 }
 
 }
