@@ -53,6 +53,8 @@ public:
   ThreadWorker();
   ~ThreadWorker();
 
+  const char*         name() const { return "worker_rtorrent"; }
+
   virtual void        init_thread();
 
   rpc::SCgi*          scgi() { return m_safe.scgi; }
@@ -61,7 +63,6 @@ public:
   void                set_xmlrpc_log(const std::string& filename);
 
   static void         start_scgi(ThreadBase* thread);
-  static void         start_log_counter(ThreadBase* thread);
   static void         msg_change_xmlrpc_log(ThreadBase* thread);
 
 private:
@@ -75,7 +76,6 @@ private:
     rpc::SCgi* scgi;
   };
 
-  rak::priority_item  m_taskTouchLog;
   safe_type           m_safe;
 
   // The following types shall only be modified while holding the
