@@ -37,8 +37,6 @@
 #ifndef RTORRENT_UI_ELEMENT_MENU_H
 #define RTORRENT_UI_ELEMENT_MENU_H
 
-#include <sigc++/functors/slot.h>
-
 #include "core/download.h"
 
 #include "element_base.h"
@@ -53,14 +51,13 @@ namespace ui {
 struct ElementMenuEntry {
   display::TextElementStringBase* m_element;
 
-  sigc::slot0<void>   m_slotFocus;
-  sigc::slot0<void>   m_slotSelect;
+  std::tr1::function<void ()>     m_slotFocus;
+  std::tr1::function<void ()>     m_slotSelect;
 };
 
 class ElementMenu : public ElementBase, public std::vector<ElementMenuEntry> {
 public:
   typedef std::vector<ElementMenuEntry> base_type;
-  typedef sigc::slot0<void>             slot_type;
 
   typedef display::WindowText         WindowText;
 
